betty.test_utils.json.linked_data module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.json.linked_data module

Test utilities for `betty.json.linked_data`.

async betty.test_utils.json.linked_data.assert_dumps_linked_data(sut: LinkedDataDumpable[Schema, _DumpT]) → _DumpT

  Dump an object’s linked data and assert it is valid.

async betty.test_utils.json.linked_data.assert_dumps_linked_data_for(sut: LinkedDataDumpableProvider[_T, Schema, _DumpT], target: _T) → _DumpT

  Dump an object’s linked data and assert it is valid.